==> haskell-kan-extensions-5.0.1-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-F8h9AOlXfjw4tW9ctXW36b
key: kan-extensions-5.0.1-F8h9AOlXfjw4tW9ctXW36b
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
abi: c6ef70053f9b4fb9e02af472fa9638f6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-F8h9AOlXfjw4tW9ctXW36b
depends:
    adjunctions-4.3-JgRDCfAwfZHGzcwRn0jHXd array-0.5.1.1 base-4.9.0.0
    comonad-5-FocVP0xchqoELxW0q31ZBF containers-0.5.7.1
    contravariant-1.4-QSyIMKSTFU5sk4KxSecCX
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    free-4.12.4-DZCTkfqdDiF4eKUVutuQ1W mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    semigroupoids-5.1-KBxlUMJdBcK6rKu26wa0Rl
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.0.1-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-E4ZgWfVsXrP8SVkhqQWNWJ
key: kan-extensions-5.0.1-E4ZgWfVsXrP8SVkhqQWNWJ
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
abi: d5eae603f601dddbc5af8a8e8c184daf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-E4ZgWfVsXrP8SVkhqQWNWJ
depends:
    adjunctions-4.3-GHyMBM8SEvq1VNbtxToJES array-0.5.1.1 base-4.9.0.0
    comonad-5-IFpew4VeZSgJKPLIcHpKjC containers-0.5.7.1
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    free-4.12.4-3djEuuVf78E7uL6ewIYMHB mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    semigroupoids-5.1-mvlh42rhjC5vNXakyMT7n
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
